pub struct TensorRtRunner { /* private fields */ }Expand description
ModelRunner that drives an immutable TensorRT engine.
Implementations
Sourceimpl TensorRtRunner
impl TensorRtRunner
Sourcepub fn new(config: TensorRtConfig) -> InferenceResult<Self>
pub fn new(config: TensorRtConfig) -> InferenceResult<Self>
Read the plan file and prepare the runner. The TensorRT
runtime / engine are not built until the first call to
execute (so a runner can be instantiated on a host without
libnvinfer for testing the config layer).